@@ -1,10 +1,11 @@
-#' @title Item Fit Indicees
+#' @title Item Fit Indices
 #' @export pairwise.item.fit
 #' @exportClass pairwise_item_fit
-#' @description function for calculating item fit indicees
-#' @details contrary to many IRT software using Ml based item parameter estimation, \code{pairwise} will not exclude persons, showing perfect response vectors (e.g. c(0,0,0) for dataset with three variables), prior to the scaling. Therefor the fit statistics computed with \code{pairwise} may deviate somewhat from the fit statistics produced by IRT software using Ml based item parameter estimation (e.g. R-package \code{eRm}, depending on the amount of persons with perfect response vectors in the data.
+#' @description function for calculating item fit indices. The procedures for calculating the fit indices are based on the formulas given in Wright & Masters, (1982, P. 100), with further clarification given in \code{http://www.rasch.org/rmt/rmt34e.htm}.
+#' @details contrary to many IRT software using Ml based item parameter estimation, \code{pairwise} will not exclude persons, showing perfect response vectors (e.g. c(0,0,0) for dataset with three variables), prior to the scaling. Therefor the fit statistics computed with \code{pairwise} may deviate somewhat from the fit statistics produced by IRT software using Ml based item parameter estimation (e.g. R-package \code{eRm}), depending on the amount of persons with perfect response vectors in the data.
 #' @param pers_obj an object of class \code{"pers"} as a result from function \code{\link{pers}}
-#' @return an object of class \code{c("pairwise_item_fit", "data.frame")} contaning item fit indicees.
+#' @return an object of class \code{c("pairwise_item_fit", "data.frame")} containing item fit indices.
+#' @references Wright, B. D., & Masters, G. N. (1982). \emph{Rating Scale Analysis.} Chicago: MESA Press.
 #' @examples ########
 #' data(sim200x3)
 #' result <- pers(pair(sim200x3))
@@ -40,11 +41,13 @@ Uqi <- sqrt(Uq2i)
 
 ## Unweighted Mean Square Ui (OUTFIT.MEANSQ)-------
 # so macht es eRm als alternative (dritte stelle hintem komma versch.):   i.outfitMSQ <- Chi/df
+#colSums(!is.na(Z2ni))
 Ui <- colSums(Z2ni, na.rm = TRUE)/Nna_v   # nicht N wegen missings!
+Uikorr <- Ui+1-mean(Ui) # korr. outfit --> siehe oRM.pdf seite 8 oben und oRM.R Zeile 115 und Ordinales_Rasch_Modell.pdf seite 68
 
 ## Standardised (Un)weighted Mean Square Ti (OUTFIT.ZSTD)-------
 UTi <- ( ( (Ui^(1/3)) -1) * (3/Uqi) ) + (Uqi/3) # ... gegencheck eRm (i.outfitZ in itemfit.ppar) formel stimmt - werte leicht unterschiedlich - in eRm werden perfecte resp. vorher rausgeworfen OK
-
+UTikorr <- ( ( (Uikorr^(1/3)) -1) * (3/Uqi) ) + (Uqi/3)
 
 #-----------------------------------------------------------------
 
@@ -55,12 +58,15 @@ Vqi <- sqrt(Vq2i)
 ## Weighted Mean Square Vi (INFIT.MEANSQ)-------
 # Vi <- colSums(Z2ni*Wni, na.rm = TRUE)/colSums(Wni, na.rm = TRUE) # eRm style -> identisch
 Vi <- colSums(Y2ni, na.rm = TRUE) / colSums(Wni, na.rm = TRUE) # ... gegencheck eRm (i.infitMSQ in itemfit.ppar) OK
+Vikorr <- Vi+1-mean(Vi) # korr. outfit --> siehe oRM.pdf seite 8 oben und oRM.R Zeile 115 und Ordinales_Rasch_Modell.pdf seite 68
 
 ## Standardised Weighted Mean Square Ti (INFIT.ZSTD)-------
 VTi <- ( (Vi^(1/3)-1) * (3/Vqi) ) + (Vqi/3) # ... gegencheck eRm (i.infitZ in itemfit.ppar) unterschiede! aber formel stimmt OK
+VTikorr <- ( (Vikorr^(1/3)-1) * (3/Vqi) ) + (Vqi/3)
 
 #-----------------------------------------------------------------
-erg <- as.data.frame(list(Chi=Chi, df=df, p=pChi, OUTFIT.MEANSQ=Ui , OUTFIT.ZSTD=UTi ,INFIT.MEANSQ=Vi, INFIT.ZSTD=VTi ))
+erg <- as.data.frame(list(Chi=round(Chi,4), df=df, p=round(pChi,4), OUTFIT.MSQ=round(Ui,4) , OUTFIT.ZSTD=round(UTi,4) ,INFIT.MSQ=round(Vi,4), INFIT.ZSTD=round(VTi,4) , OUTFIT.MSQ.REL=round(Uikorr,4), OUTFIT.ZSTD.REL=round(UTikorr,4) ,INFIT.MSQ.REL=round(Vikorr,4), INFIT.ZSTD.REL=round(VTikorr,4) ))
+
 class(erg) <- c("pairwise_item_fit","data.frame")
 return( erg )
 }
