@@ -2,11 +2,11 @@
 #' @export ptbis
 #' @description Calculation of the point biserial correlations for dicho- or polytomous item categories with total scale (person parameter).
 #'  
-#' @details to come ...
+#' @details no details in the moment.
 #' @param y either an object of class \code{"pers"}, or an numeric vector as an result of any scaling approach (WLE, MLE, Rawscore, etc. ) relating to the Items (columns) in \code{daten}.    
-#' @param daten if argument y is not an object of class \code{"pers"}, a \code{data.frame}, potentially with missing values, comprising dicho- or polytomous items (columns). 
+#' @param daten if argument y is not an object of class \code{"pers"}, a \code{"data.frame"}, potentially with missing values, comprising dicho- or polytomous items (columns). 
 
-#' @return An object of class "data.frame" and "ptbis" containing item statistics.
+#' @return An object of class \code{c("data.frame", "ptbis")} containing item statistics.
 #' @exportClass ptbis
 #' @examples ######################
 #' ########
@@ -30,7 +30,14 @@ ptbis <- function(y, daten=NULL){# daten = data.frame mit polytomen variablen; y
   if(class(daten)!="data.frame"){stop("daten must be a data.frame")}
   stopifnot(dim(daten)[1]==length(abil))
   datenl <- as.list(daten)
-  # erg <- lapply(datenl, polyptb, abil)
-  erg <- t(as.data.frame(lapply(datenl, polyptb, abil)))
-  return(erg)
+  erglist <- lapply(datenl, polyptb, abil)
+  ##### 
+  maxLen <- max(sapply(erglist, length))
+  # create a new list with elements padded out with NAs
+  newM <- lapply(erglist, function(.ele){c(.ele, rep(NA, maxLen))[1:maxLen]})
+  ergmat <- do.call(rbind, newM)
+  
+  colnames(ergmat) <- c(sapply(0:((dim(ergmat)[2]/2)-1),function(x){paste(x,c("rptb","n"),sep=".")}))
+ 
+  return(ergmat)
 }
